# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 4.3.0


from . import AWSObject
from . import AWSProperty
from troposphere import Tags
from .validators import boolean
from .validators import integer


class ClearTimer(AWSProperty):
    props = {
        'TimerName': (str, False),
    }


class Firehose(AWSProperty):
    props = {
        'DeliveryStreamName': (str, False),
        'Separator': (str, False),
    }


class IotEvents(AWSProperty):
    props = {
        'InputName': (str, False),
    }


class IotTopicPublish(AWSProperty):
    props = {
        'MqttTopic': (str, False),
    }


class Lambda(AWSProperty):
    props = {
        'FunctionArn': (str, False),
    }


class ResetTimer(AWSProperty):
    props = {
        'TimerName': (str, False),
    }


class SetTimer(AWSProperty):
    props = {
        'Seconds': (integer, False),
        'TimerName': (str, False),
    }


class SetVariable(AWSProperty):
    props = {
        'Value': (str, False),
        'VariableName': (str, False),
    }


class Sns(AWSProperty):
    props = {
        'TargetArn': (str, False),
    }


class Sqs(AWSProperty):
    props = {
        'QueueUrl': (str, False),
        'UseBase64': (boolean, False),
    }


class Action(AWSProperty):
    props = {
        'ClearTimer': (ClearTimer, False),
        'Firehose': (Firehose, False),
        'IotEvents': (IotEvents, False),
        'IotTopicPublish': (IotTopicPublish, False),
        'Lambda': (Lambda, False),
        'ResetTimer': (ResetTimer, False),
        'SetTimer': (SetTimer, False),
        'SetVariable': (SetVariable, False),
        'Sns': (Sns, False),
        'Sqs': (Sqs, False),
    }


class Event(AWSProperty):
    props = {
        'Actions': ([Action], False),
        'Condition': (str, False),
        'EventName': (str, False),
    }


class OnEnter(AWSProperty):
    props = {
        'Events': ([Event], False),
    }


class OnExit(AWSProperty):
    props = {
        'Events': ([Event], False),
    }


class TransitionEvent(AWSProperty):
    props = {
        'Actions': ([Action], False),
        'Condition': (str, False),
        'EventName': (str, False),
        'NextState': (str, False),
    }


class OnInput(AWSProperty):
    props = {
        'Events': ([Event], False),
        'TransitionEvents': ([TransitionEvent], False),
    }


class State(AWSProperty):
    props = {
        'OnEnter': (OnEnter, False),
        'OnExit': (OnExit, False),
        'OnInput': (OnInput, False),
        'StateName': (str, False),
    }


class DetectorModelDefinition(AWSProperty):
    props = {
        'InitialStateName': (str, False),
        'States': ([State], False),
    }


class DetectorModel(AWSObject):
    resource_type = "AWS::IoTEvents::DetectorModel"

    props = {
        'DetectorModelDefinition': (DetectorModelDefinition, False),
        'DetectorModelDescription': (str, False),
        'DetectorModelName': (str, False),
        'Key': (str, False),
        'RoleArn': (str, False),
        'Tags': (Tags, False),
    }


class Attribute(AWSProperty):
    props = {
        'JsonPath': (str, False),
    }


class InputDefinition(AWSProperty):
    props = {
        'Attributes': ([Attribute], False),
    }


class Input(AWSObject):
    resource_type = "AWS::IoTEvents::Input"

    props = {
        'InputDefinition': (InputDefinition, False),
        'InputDescription': (str, False),
        'InputName': (str, False),
        'Tags': (Tags, False),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 8.1.0


from . import AWSObject
from . import AWSProperty
from troposphere import Tags
from .validators import boolean


class BasicAuthConfig(AWSProperty):
    props = {
        'EnableBasicAuth': (boolean, False),
        'Password': (str, True),
        'Username': (str, True),
    }


class EnvironmentVariable(AWSProperty):
    props = {
        'Name': (str, True),
        'Value': (str, True),
    }


class AutoBranchCreationConfig(AWSProperty):
    props = {
        'AutoBranchCreationPatterns': ([str], False),
        'BasicAuthConfig': (BasicAuthConfig, False),
        'BuildSpec': (str, False),
        'EnableAutoBranchCreation': (boolean, False),
        'EnableAutoBuild': (boolean, False),
        'EnablePullRequestPreview': (boolean, False),
        'EnvironmentVariables': ([EnvironmentVariable], False),
        'PullRequestEnvironmentName': (str, False),
        'Stage': (str, False),
    }


class CustomRule(AWSProperty):
    props = {
        'Condition': (str, False),
        'Source': (str, True),
        'Status': (str, False),
        'Target': (str, True),
    }


class App(AWSObject):
    resource_type = "AWS::Amplify::App"

    props = {
        'AccessToken': (str, False),
        'AutoBranchCreationConfig': (AutoBranchCreationConfig, False),
        'BasicAuthConfig': (BasicAuthConfig, False),
        'BuildSpec': (str, False),
        'CustomRules': ([CustomRule], False),
        'Description': (str, False),
        'EnvironmentVariables': ([EnvironmentVariable], False),
        'IAMServiceRole': (str, False),
        'Name': (str, True),
        'OauthToken': (str, False),
        'Repository': (str, False),
        'Tags': (Tags, False),
    }


class Branch(AWSObject):
    resource_type = "AWS::Amplify::Branch"

    props = {
        'AppId': (str, True),
        'BasicAuthConfig': (BasicAuthConfig, False),
        'BranchName': (str, True),
        'BuildSpec': (str, False),
        'Description': (str, False),
        'EnableAutoBuild': (boolean, False),
        'EnablePullRequestPreview': (boolean, False),
        'EnvironmentVariables': ([EnvironmentVariable], False),
        'PullRequestEnvironmentName': (str, False),
        'Stage': (str, False),
        'Tags': (Tags, False),
    }


class SubDomainSetting(AWSProperty):
    props = {
        'BranchName': (str, True),
        'Prefix': (str, True),
    }


class Domain(AWSObject):
    resource_type = "AWS::Amplify::Domain"

    props = {
        'AppId': (str, True),
        'DomainName': (str, True),
        'SubDomainSettings': ([SubDomainSetting], True),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 5.3.0


from . import AWSObject
from . import AWSProperty
from .validators import boolean


class S3(AWSProperty):
    props = {
        'Bucket': (str, True),
        'Key': (str, True),
        'ObjectVersion': (str, False),
    }


class Code(AWSProperty):
    props = {
        'S3': (S3, True),
    }


class GitHubRepository(AWSObject):
    resource_type = "AWS::CodeStar::GitHubRepository"

    props = {
        'Code': (Code, False),
        'EnableIssues': (boolean, False),
        'IsPrivate': (boolean, False),
        'RepositoryAccessToken': (str, True),
        'RepositoryDescription': (str, False),
        'RepositoryName': (str, True),
        'RepositoryOwner': (str, True),
    }



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, Tags
from .compat import policytypes
from .validators import boolean, integer_range, key_usage_type


class Alias(AWSObject):
    resource_type = "AWS::KMS::Alias"

    props = {
        'AliasName': (str, True),
        'TargetKeyId': (str, True)
    }


class Key(AWSObject):
    resource_type = "AWS::KMS::Key"

    props = {
        'Description': (str, False),
        'Enabled': (boolean, False),
        'EnableKeyRotation': (boolean, False),
        'KeyPolicy': (policytypes, True),
        'KeyUsage': (key_usage_type, False),
        'PendingWindowInDays': (integer_range(7, 30), False),
        'Tags': ((Tags, list), False)
    }



from . import AWSObject, AWSProperty
from .validators import boolean


class ParameterObjectAttribute(AWSProperty):
    props = {
        'Key': (str, True),
        'StringValue': (str, False),
    }


class ParameterObject(AWSProperty):
    props = {
        'Attributes': ([ParameterObjectAttribute], True),
        'Id': (str, True),
    }


class ParameterValue(AWSProperty):
    props = {
        'Id': (str, True),
        'StringValue': (str, True),
    }


class ObjectField(AWSProperty):
    props = {
        'Key': (str, True),
        'RefValue': (str, False),
        'StringValue': (str, False),
    }


class PipelineObject(AWSProperty):
    props = {
        'Fields': ([ObjectField], True),
        'Id': (str, True),
        'Name': (str, True),
    }


class PipelineTag(AWSProperty):
    props = {
        'Key': (str, True),
        'Value': (str, True),
    }


class Pipeline(AWSObject):
    resource_type = "AWS::DataPipeline::Pipeline"

    props = {
        'Activate': (boolean, False),
        'Description': (str, False),
        'Name': (str, True),
        'ParameterObjects': ([ParameterObject], False),
        'ParameterValues': ([ParameterValue], False),
        'PipelineObjects': ([PipelineObject], True),
        'PipelineTags': ([PipelineTag], False),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 5.3.0


from . import AWSObject
from . import AWSProperty


class Admins(AWSProperty):
    props = {
    }


class DataLakeSettings(AWSObject):
    resource_type = "AWS::LakeFormation::DataLakeSettings"

    props = {
        'Admins': (Admins, False),
    }


class DataLakePrincipal(AWSProperty):
    props = {
        'DataLakePrincipalIdentifier': (str, False),
    }


class DatabaseResource(AWSProperty):
    props = {
        'Name': (str, False),
    }


class TableResource(AWSProperty):
    props = {
        'DatabaseName': (str, False),
        'Name': (str, False),
    }


class Resource(AWSProperty):
    props = {
        'DatabaseResource': (DatabaseResource, False),
        'TableResource': (TableResource, False),
    }


class Permissions(AWSObject):
    resource_type = "AWS::LakeFormation::Permissions"

    props = {
        'DataLakePrincipal': (DataLakePrincipal, True),
        'Permissions': ([str], False),
        'PermissionsWithGrantOption': ([str], False),
        'Resource': (Resource, True),
    }



# Copyright (c) 2012-2018, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags
from .validators import boolean, integer, json_checker, double


class RetentionPeriod(AWSProperty):
    props = {
        'NumberOfDays': (integer, False),
        'Unlimited': (boolean, False),
    }


class Channel(AWSObject):
    resource_type = "AWS::IoTAnalytics::Channel"

    props = {
        'ChannelName': (str, False),
        'RetentionPeriod': (RetentionPeriod, False),
        'Tags': ((Tags, list), False),
    }


class AddAttributes(AWSProperty):
    props = {
        'Attributes': (json_checker, False),
        'Name': (str, False),
        'Next': (str, False),
    }


class ActivityChannel(AWSProperty):
    props = {
        'ChannelName': (str, False),
        'Name': (str, False),
        'Next': (str, False),
    }


class Datastore(AWSProperty):
    props = {
        'DatastoreName': (str, False),
        'Name': (str, False),
    }


class DeviceRegistryEnrich(AWSProperty):
    props = {
        'Attribute': (str, False),
        'Name': (str, False),
        'Next': (str, False),
        'RoleArn': (str, False),
        'ThingName': (str, False),
    }


class DeviceShadowEnrich(AWSProperty):
    props = {
        'Attribute': (str, False),
        'Name': (str, False),
        'Next': (str, False),
        'RoleArn': (str, False),
        'ThingName': (str, False),
    }


class Filter(AWSProperty):
    props = {
        'Filter': (str, False),
        'Name': (str, False),
        'Next': (str, False),
    }


class Lambda(AWSProperty):
    props = {
        'BatchSize': (integer, False),
        'LambdaName': (str, False),
        'Name': (str, False),
        'Next': (str, False),
    }


class Math(AWSProperty):
    props = {
        'Attribute': (str, False),
        'Math': (str, False),
        'Name': (str, False),
        'Next': (str, False),
    }


class RemoveAttributes(AWSProperty):
    props = {
        'Attributes': ([str], False),
        'Name': (str, False),
        'Next': (str, False),
    }


class SelectAttributes(AWSProperty):
    props = {
        'Attributes': ([str], False),
        'Name': (str, False),
        'Next': (str, False),
    }


class Activity(AWSProperty):
    props = {
        'AddAttributes': (AddAttributes, False),
        'Channel': (ActivityChannel, False),
        'Datastore': (Datastore, False),
        'DeviceRegistryEnrich': (DeviceRegistryEnrich, False),
        'DeviceShadowEnrich': (DeviceShadowEnrich, False),
        'Filter': (Filter, False),
        'Lambda': (Lambda, False),
        'Math': (Math, False),
        'RemoveAttributes': (RemoveAttributes, False),
        'SelectAttributes': (SelectAttributes, False),
    }


class Pipeline(AWSObject):
    resource_type = "AWS::IoTAnalytics::Pipeline"

    props = {
        'PipelineActivities': ([Activity], True),
        'PipelineName': (str, False),
        'Tags': ((Tags, list), False),
    }


class RetentionPeriod(AWSProperty):
    props = {
        'NumberOfDays': (integer, False),
        'Unlimited': (boolean, False),
    }


class Datastore(AWSObject):
    resource_type = "AWS::IoTAnalytics::Datastore"

    props = {
        'DatastoreName': (str, False),
        'RetentionPeriod': (RetentionPeriod, False),
        'Tags': ((Tags, list), False),
    }


class ResourceConfiguration(AWSProperty):
    props = {
        'ComputeType': (str, True),
        'VolumeSizeInGB': (integer, True),
    }


class DatasetContentVersionValue(AWSProperty):
    props = {
        'DatasetName': (str, False),
    }


class OutputFileUriValue(AWSProperty):
    props = {
        'FileName': (str, False),
    }


class Variable(AWSProperty):
    props = {
        'DatasetContentVersionValue': (DatasetContentVersionValue, False),
        'DoubleValue': (double, False),
        'OutputFileUriValue': (OutputFileUriValue, False),
        'StringValue': (str, False),
        'VariableName': (str, False)
    }


class ContainerAction(AWSProperty):
    props = {
        'ExecutionRoleArn': (str, True),
        'Image': (str, True),
        'ResourceConfiguration': (ResourceConfiguration, False),
        'Variables': ([Variable], False),
    }


class DeltaTime(AWSProperty):
    props = {
        'TimeExpression': (str, True),
        'OffsetSeconds': (integer, True),
    }


class QueryActionFilter(AWSProperty):
    props = {
        'DeltaTime': (DeltaTime, False),
    }


class QueryAction(AWSProperty):
    props = {
        'Filters': ([QueryActionFilter], False),
        'SqlQuery': (str, False),
    }


class Action(AWSProperty):
    props = {
        'ActionName': (str, True),
        'ContainerAction': (ContainerAction, False),
        'QueryAction': (QueryAction, False)
    }


class IotEventsDestinationConfiguration(AWSProperty):
    props = {
        'InputName': (str, True),
        'RoleArn': (str, True),
    }


class GlueConfiguration(AWSProperty):
    props = {
        'DatabaseName': (str, True),
        'TableName': (str, True),
    }


class S3DestinationConfiguration(AWSProperty):
    props = {
        'Bucket': (str, True),
        'GlueConfiguration': (GlueConfiguration, False),
        'Key': (str, True),
        'RoleArn': (str, True),
    }


class DatasetContentDeliveryRuleDestination(AWSProperty):
    props = {
        'IotEventsDestinationConfiguration':
            (IotEventsDestinationConfiguration, False),
        'S3DestinationConfiguration': (S3DestinationConfiguration, False),
    }


class DatasetContentDeliveryRule(AWSProperty):
    props = {
        'Destination': (DatasetContentDeliveryRuleDestination, True),
        'EntryName': (str, False),
    }


class Schedule(AWSProperty):
    props = {
        'ScheduleExpression': (str, True),
    }


class TriggeringDataset(AWSProperty):
    props = {
        'DatasetName': (str, True),
    }


class Trigger(AWSProperty):
    props = {
        'Schedule': (Schedule, False),
        'TriggeringDataset': (TriggeringDataset, False),
    }


class VersioningConfiguration(AWSProperty):
    props = {
        'MaxVersions': (integer, False),
        'Unlimited': (boolean, False),
    }


class Dataset(AWSObject):
    resource_type = "AWS::IoTAnalytics::Dataset"

    props = {
        'Actions': ([Action], True),
        'ContentDeliveryRules': ([DatasetContentDeliveryRule], False),
        'DatasetName': (str, False),
        'RetentionPeriod': (RetentionPeriod, False),
        'Tags': (Tags, False),
        'Triggers': ([Trigger], False),
        'VersioningConfiguration': (VersioningConfiguration, False),
    }



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags
from .compat import policytypes
from .validators import integer, boolean, status
from .validators import iam_path, iam_role_name, iam_group_name, iam_user_name

Active = "Active"
Inactive = "Inactive"


class AccessKey(AWSObject):
    resource_type = "AWS::IAM::AccessKey"

    props = {
        'Serial': (integer, False),
        'Status': (status, False),
        'UserName': (str, True),
    }


class PolicyType(AWSObject):
    resource_type = "AWS::IAM::Policy"

    props = {
        'Groups': ([str], False),
        'PolicyDocument': (policytypes, True),
        'PolicyName': (str, True),
        'Roles': ([str], False),
        'Users': ([str], False),
    }


class Policy(AWSProperty):
    props = {
        'PolicyDocument': (policytypes, True),
        'PolicyName': (str, True),
    }


PolicyProperty = Policy


class Group(AWSObject):
    resource_type = "AWS::IAM::Group"

    props = {
        'GroupName': (iam_group_name, False),
        'ManagedPolicyArns': ([str], False),
        'Path': (iam_path, False),
        'Policies': ([Policy], False),
    }


class InstanceProfile(AWSObject):
    resource_type = "AWS::IAM::InstanceProfile"

    props = {
        'Path': (iam_path, False),
        'Roles': (list, True),
        'InstanceProfileName': (str, False),
    }


class Role(AWSObject):
    resource_type = "AWS::IAM::Role"

    props = {
        'AssumeRolePolicyDocument': (policytypes, True),
        'Description': (str, False),
        'ManagedPolicyArns': ([str], False),
        'MaxSessionDuration': (integer, False),
        'Path': (iam_path, False),
        'PermissionsBoundary': (str, False),
        'Policies': ([Policy], False),
        'RoleName': (iam_role_name, False),
        'Tags': ((Tags, list), False),
    }


class ServiceLinkedRole(AWSObject):
    resource_type = "AWS::IAM::ServiceLinkedRole"

    props = {
        'AWSServiceName': (str, True),
        'CustomSuffix': (str, False),
        'Description': (str, False),
    }


class LoginProfile(AWSProperty):
    props = {
        'Password': (str, True),
        'PasswordResetRequired': (boolean, False),
    }


class User(AWSObject):
    resource_type = "AWS::IAM::User"

    props = {
        'Groups': ([str], False),
        'LoginProfile': (LoginProfile, False),
        'ManagedPolicyArns': ([str], False),
        'Path': (iam_path, False),
        'PermissionsBoundary': (str, False),
        'Policies': ([Policy], False),
        'Tags': (Tags, False),
        'UserName': (iam_user_name, False),
    }


class UserToGroupAddition(AWSObject):
    resource_type = "AWS::IAM::UserToGroupAddition"

    props = {
        'GroupName': (str, True),
        'Users': (list, True),
    }


class ManagedPolicy(AWSObject):
    resource_type = "AWS::IAM::ManagedPolicy"

    props = {
        'Description': (str, False),
        'Groups': ([str], False),
        'ManagedPolicyName': (str, False),
        'Path': (iam_path, False),
        'PolicyDocument': (policytypes, True),
        'Roles': ([str], False),
        'Users': ([str], False),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 8.1.0


from . import AWSObject
from . import AWSProperty
from troposphere import Tags
from .validators import boolean
from .validators import integer


class EgressFilter(AWSProperty):
    props = {
        'Type': (str, True),
    }


class MeshSpec(AWSProperty):
    props = {
        'EgressFilter': (EgressFilter, False),
    }


class Mesh(AWSObject):
    resource_type = "AWS::AppMesh::Mesh"

    props = {
        'MeshName': (str, True),
        'Spec': (MeshSpec, False),
        'Tags': (Tags, False),
    }


class Duration(AWSProperty):
    props = {
        'Unit': (str, True),
        'Value': (integer, True),
    }


class GrpcRetryPolicy(AWSProperty):
    props = {
        'GrpcRetryEvents': ([str], False),
        'HttpRetryEvents': ([str], False),
        'MaxRetries': (integer, True),
        'PerRetryTimeout': (Duration, True),
        'TcpRetryEvents': ([str], False),
    }


class WeightedTarget(AWSProperty):
    props = {
        'VirtualNode': (str, True),
        'Weight': (integer, True),
    }


class GrpcRouteAction(AWSProperty):
    props = {
        'WeightedTargets': ([WeightedTarget], True),
    }


class MatchRange(AWSProperty):
    props = {
        'End': (integer, True),
        'Start': (integer, True),
    }


class GrpcRouteMetadataMatchMethod(AWSProperty):
    props = {
        'Exact': (str, False),
        'Prefix': (str, False),
        'Range': (MatchRange, False),
        'Regex': (str, False),
        'Suffix': (str, False),
    }


class GrpcRouteMetadata(AWSProperty):
    props = {
        'Invert': (boolean, False),
        'Match': (GrpcRouteMetadataMatchMethod, False),
        'Name': (str, True),
    }


class GrpcRouteMatch(AWSProperty):
    props = {
        'Metadata': ([GrpcRouteMetadata], False),
        'MethodName': (str, False),
        'ServiceName': (str, False),
    }


class GrpcRoute(AWSProperty):
    props = {
        'Action': (GrpcRouteAction, True),
        'Match': (GrpcRouteMatch, True),
        'RetryPolicy': (GrpcRetryPolicy, False),
    }


class HttpRetryPolicy(AWSProperty):
    props = {
        'HttpRetryEvents': ([str], False),
        'MaxRetries': (integer, True),
        'PerRetryTimeout': (Duration, True),
        'TcpRetryEvents': ([str], False),
    }


class HttpRouteAction(AWSProperty):
    props = {
        'WeightedTargets': ([WeightedTarget], True),
    }


class HeaderMatchMethod(AWSProperty):
    props = {
        'Exact': (str, False),
        'Prefix': (str, False),
        'Range': (MatchRange, False),
        'Regex': (str, False),
        'Suffix': (str, False),
    }


class HttpRouteHeader(AWSProperty):
    props = {
        'Invert': (boolean, False),
        'Match': (HeaderMatchMethod, False),
        'Name': (str, True),
    }


class HttpRouteMatch(AWSProperty):
    props = {
        'Headers': ([HttpRouteHeader], False),
        'Method': (str, False),
        'Prefix': (str, True),
        'Scheme': (str, False),
    }


class HttpRoute(AWSProperty):
    props = {
        'Action': (HttpRouteAction, True),
        'Match': (HttpRouteMatch, True),
        'RetryPolicy': (HttpRetryPolicy, False),
    }


class TcpRouteAction(AWSProperty):
    props = {
        'WeightedTargets': ([WeightedTarget], True),
    }


class TcpRoute(AWSProperty):
    props = {
        'Action': (TcpRouteAction, True),
    }


class RouteSpec(AWSProperty):
    props = {
        'GrpcRoute': (GrpcRoute, False),
        'Http2Route': (HttpRoute, False),
        'HttpRoute': (HttpRoute, False),
        'Priority': (integer, False),
        'TcpRoute': (TcpRoute, False),
    }


class Route(AWSObject):
    resource_type = "AWS::AppMesh::Route"

    props = {
        'MeshName': (str, True),
        'RouteName': (str, True),
        'Spec': (RouteSpec, True),
        'Tags': (Tags, False),
        'VirtualRouterName': (str, True),
    }


class VirtualServiceBackend(AWSProperty):
    props = {
        'VirtualServiceName': (str, True),
    }


class Backend(AWSProperty):
    props = {
        'VirtualService': (VirtualServiceBackend, False),
    }


class HealthCheck(AWSProperty):
    props = {
        'HealthyThreshold': (integer, True),
        'IntervalMillis': (integer, True),
        'Path': (str, False),
        'Port': (integer, False),
        'Protocol': (str, True),
        'TimeoutMillis': (integer, True),
        'UnhealthyThreshold': (integer, True),
    }


class PortMapping(AWSProperty):
    props = {
        'Port': (integer, True),
        'Protocol': (str, True),
    }


class Listener(AWSProperty):
    props = {
        'HealthCheck': (HealthCheck, False),
        'PortMapping': (PortMapping, True),
    }


class FileAccessLog(AWSProperty):
    props = {
        'Path': (str, True),
    }


class AccessLog(AWSProperty):
    props = {
        'File': (FileAccessLog, False),
    }


class Logging(AWSProperty):
    props = {
        'AccessLog': (AccessLog, False),
    }


class AwsCloudMapInstanceAttribute(AWSProperty):
    props = {
        'Key': (str, True),
        'Value': (str, True),
    }


class AwsCloudMapServiceDiscovery(AWSProperty):
    props = {
        'Attributes': ([AwsCloudMapInstanceAttribute], False),
        'NamespaceName': (str, True),
        'ServiceName': (str, True),
    }


class DnsServiceDiscovery(AWSProperty):
    props = {
        'Hostname': (str, True),
    }


class ServiceDiscovery(AWSProperty):
    props = {
        'AWSCloudMap': (AwsCloudMapServiceDiscovery, False),
        'DNS': (DnsServiceDiscovery, False),
    }


class VirtualNodeSpec(AWSProperty):
    props = {
        'Backends': ([Backend], False),
        'Listeners': ([Listener], False),
        'Logging': (Logging, False),
        'ServiceDiscovery': (ServiceDiscovery, False),
    }


class VirtualNode(AWSObject):
    resource_type = "AWS::AppMesh::VirtualNode"

    props = {
        'MeshName': (str, True),
        'Spec': (VirtualNodeSpec, True),
        'Tags': (Tags, False),
        'VirtualNodeName': (str, True),
    }


class VirtualRouterListener(AWSProperty):
    props = {
        'PortMapping': (PortMapping, True),
    }


class VirtualRouterSpec(AWSProperty):
    props = {
        'Listeners': ([VirtualRouterListener], True),
    }


class VirtualRouter(AWSObject):
    resource_type = "AWS::AppMesh::VirtualRouter"

    props = {
        'MeshName': (str, True),
        'Spec': (VirtualRouterSpec, True),
        'Tags': (Tags, False),
        'VirtualRouterName': (str, True),
    }


class VirtualNodeServiceProvider(AWSProperty):
    props = {
        'VirtualNodeName': (str, True),
    }


class VirtualRouterServiceProvider(AWSProperty):
    props = {
        'VirtualRouterName': (str, True),
    }


class VirtualServiceProvider(AWSProperty):
    props = {
        'VirtualNode': (VirtualNodeServiceProvider, False),
        'VirtualRouter': (VirtualRouterServiceProvider, False),
    }


class VirtualServiceSpec(AWSProperty):
    props = {
        'Provider': (VirtualServiceProvider, False),
    }


class VirtualService(AWSObject):
    resource_type = "AWS::AppMesh::VirtualService"

    props = {
        'MeshName': (str, True),
        'Spec': (VirtualServiceSpec, True),
        'Tags': (Tags, False),
        'VirtualServiceName': (str, True),
    }



# Copyright (c) 2012-2017, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import integer


class Repository(AWSProperty):
    props = {
        'PathComponent': (str, True),
        'RepositoryUrl': (str, True),
    }


class EnvironmentEC2(AWSObject):
    resource_type = "AWS::Cloud9::EnvironmentEC2"

    props = {
        'AutomaticStopTimeMinutes': (integer, False),
        'Description': (str, False),
        'InstanceType': (str, True),
        'Name': (str, False),
        'OwnerArn': (str, False),
        'Repositories': ([Repository], False),
        'SubnetId': (str, False),
    }



# Copyright (c) 2015, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags
from .validators import boolean, integer


class WorkspaceProperties(AWSProperty):
    props = {
        'ComputeTypeName': (str, False),
        'RootVolumeSizeGib': (integer, False),
        'RunningMode': (str, False),
        'RunningModeAutoStopTimeoutInMinutes': (integer, False),
        'UserVolumeSizeGib': (integer, False),
    }


class Workspace(AWSObject):
    resource_type = "AWS::WorkSpaces::Workspace"

    props = {
        'BundleId': (str, True),
        'DirectoryId': (str, True),
        'UserName': (str, True),
        'RootVolumeEncryptionEnabled': (boolean, False),
        'Tags': (Tags, False),
        'UserVolumeEncryptionEnabled': (boolean, False),
        'VolumeEncryptionKey': (str, False),
        'WorkspaceProperties': (WorkspaceProperties, False),
    }
